<?php

namespace Trackeasy\Classes;

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * TE_Trackeasy_Admin class
 */
class TE_Trackeasy_Admin
{
    /**
     * TE_Trackeasy_Admin constructor
     */
    public function __construct()
    {
        register_activation_hook(TE_TRACKEASY_CORE, [$this, 'te_add_setting_options']);
        add_action('admin_menu', [$this, 'te_register_menu_pages']);
        add_action('admin_post_te_save_setting_options', [$this, 'te_save_setting_options']);
    }

    /**
     * Adds the TrackEasy plugin options to the database.
     *
     * @return void
     * @access public
     */
    public function te_add_setting_options(): void
    {
        $trackeasy_api_key = TE_Trackeasy_Options::TE_API_KEY;

        if (!get_option($trackeasy_api_key)) {
            add_option($trackeasy_api_key);
        }
    }

    /**
     * Adds the TrackEasy plugin admin menu pages to the WordPress admin menu.
     *
     * @return void
     * @access public
     */
    public function te_register_menu_pages(): void
    {
        $menu_slug = 'te-trackeasy';

        add_menu_page(
            'TrackEasy',
            'TrackEasy',
            'manage_options',
            $menu_slug,
            '',
            'dashicons-analytics',
            6
        );

        add_submenu_page(
            $menu_slug,
            sprintf(__('%s Settings', 'trackeasy'), 'TrackEasy'),
            __('Settings', 'trackeasy'),
            'manage_options',
            $menu_slug,
            [$this, 'te_display_settings_page'],
        );

        add_submenu_page(
            $menu_slug,
            sprintf(__('%s Setup Guide', 'trackeasy'), 'TrackEasy'),
            __('Setup Guide', 'trackeasy'),
            'manage_options',
            'te-trackeasy-setup-guide',
            [$this, 'te_display_setup_guide_page'],
        );
    }

    /**
     * Displays the TrackEasy plugin setup guide page.
     *
     * @return void
     * @access public
     */
    public function te_display_setup_guide_page(): void
    {
        $supported_cf7_fields = [];
        foreach(TE_Trackeasy_CF7_Integration::$allowed_cf7_field_types as $field_type){
            $supported_cf7_fields[] = "<code>[{$field_type}]</code>";
        }
        include_once(TE_TRACKEASY_PATH . 'page-templates/template-setup-guide.php');
    }

    /**
     * Displays the TrackEasy plugin settings page.
     *
     * @return void
     * @access public
     */
    public function te_display_settings_page(): void
    {
        $trackeasy_api_key = TE_Trackeasy_Options::TE_API_KEY;
        include_once(TE_TRACKEASY_PATH . 'page-templates/template-settings.php');
    }

    /**
     * Saves the TrackEasy plugin settings to the database.
     *
     * @return void
     * @access public
     */
    public function te_save_setting_options(): void
    {
        if (!current_user_can('manage_options')) {
            wp_die(__('You are not allowed to access this page.', 'trackeasy'));
        }

        check_admin_referer('te_setting_options_verify');

        update_option(
            TE_Trackeasy_Options::TE_API_KEY,
            TE_Trackeasy_Sanitiser::te_sanitise_field_value('text', $_POST[TE_Trackeasy_Options::TE_API_KEY])
        );

        wp_redirect(admin_url('admin.php?page=te-trackeasy&status=1'));
    }
}
